@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
+ *   Copyright (C) 2005-2009 by Rajko Albrecht                             *
  *   ral@alwins-world.de                                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,6 +20,7 @@
 #include "kiolistener.h"
 #include "kiosvn.h"
 #include "kdesvndinterface.h"
+#include "kio_macros.h"
 
 #include <kdebug.h>
 #include <klocale.h>
@@ -28,6 +29,7 @@
 
 namespace KIO {
 
+
 KioListener::KioListener(KIO::kio_svnProtocol*_par)
     : svn::ContextListener(),m_notifyCounter(0),m_External(false),m_HasChanges(false),m_FirstTxDelta(false),m_Canceld(false)
 {
@@ -57,11 +59,7 @@ bool KioListener::contextCancel()
 bool KioListener::contextGetLogMessage (QString & msg,const svn::CommitItemList&_items)
 {
     Q_UNUSED(_items);
-    OrgKdeKdesvndInterface kdesvndInterface( "org.kde.kded", "/modules/kdesvnd", QDBusConnection::sessionBus() );
-    if(!kdesvndInterface.isValid()) {
-       kWarning() << "Communication with KDED:KdeSvnd failed";
-       return false;
-    }
+    CON_DBUS_VAL(false);
 
     QDBusReply<QStringList> res= kdesvndInterface.get_logmsg();
 
@@ -88,6 +86,9 @@ void KioListener::contextNotify (const char * path,svn_wc_notify_action_t action
     if (par->wasKilled()) {
         return;
     }
+    if (par->checkKioCancel()) {
+        m_Canceld = true;
+    }
     QString userstring;
 
     switch(action) {
@@ -259,11 +260,7 @@ KioListener::contextSslServerTrustPrompt (const SslServerTrustData & data, apr_u
     Q_UNUSED(acceptedFailures);
     QDBusReply<int> res;
 
-    OrgKdeKdesvndInterface kdesvndInterface( "org.kde.kded", "/modules/kdesvnd", QDBusConnection::sessionBus() );
-    if(!kdesvndInterface.isValid()) {
-       kWarning() << "Communication with KDED:KdeSvnd failed";
-       return DONT_ACCEPT;
-    }
+    CON_DBUS_VAL(DONT_ACCEPT);
     res = kdesvndInterface.get_sslaccept(data.hostname,
             data.fingerprint, data.validFrom, data.validUntil, data.issuerDName, data.realm);
 
@@ -292,11 +289,7 @@ bool KioListener::contextLoadSslClientCertPw(QString&password,const QString&real
 {
     QDBusReply<QString> res;
 
-    OrgKdeKdesvndInterface kdesvndInterface( "org.kde.kded", "/modules/kdesvnd", QDBusConnection::sessionBus() );
-    if(!kdesvndInterface.isValid()) {
-        kWarning() << "Communication with KDED:KdeSvnd failed";
-        return false;
-    }
+    CON_DBUS_VAL(false);
     res=kdesvndInterface.load_sslclientcertpw(realm);
     if (!res.isValid()) {
         kWarning() << "Unexpected reply type";
@@ -310,11 +303,7 @@ bool KioListener::contextSslClientCertPrompt (QString & certFile)
 {
     QDBusReply<QString> res;
 
-    OrgKdeKdesvndInterface kdesvndInterface( "org.kde.kded", "/modules/kdesvnd", QDBusConnection::sessionBus() );
-    if(!kdesvndInterface.isValid()) {
-       kWarning() << "Communication with KDED:KdeSvnd failed";
-       return false;
-    }
+    CON_DBUS_VAL(false);
     res=kdesvndInterface.get_sslclientcertfile();
     if (!res.isValid()) {
         kWarning() << "Unexpected reply type";
@@ -340,11 +329,7 @@ bool KioListener::contextGetSavedLogin (const QString & realm,QString & username
 {
     QDBusReply<QStringList> res;
 
-    OrgKdeKdesvndInterface kdesvndInterface( "org.kde.kded", "/modules/kdesvnd", QDBusConnection::sessionBus() );
-    if(!kdesvndInterface.isValid()) {
-        kWarning() << "Communication with KDED:KdeSvnd failed";
-        return false;
-    }
+    CON_DBUS_VAL(false);
     res=kdesvndInterface.get_saved_login(realm,username);
     if (!res.isValid()) {
         kWarning() << "Unexpected reply type";
@@ -372,11 +357,7 @@ bool KioListener::contextGetLogin (const QString & realm, QString & username, QS
 {
     QDBusReply<QStringList> res;
 
-    OrgKdeKdesvndInterface kdesvndInterface( "org.kde.kded", "/modules/kdesvnd", QDBusConnection::sessionBus() );
-    if(!kdesvndInterface.isValid()) {
-       kWarning() << "Communication with KDED:KdeSvnd failed";
-       return false;
-    }
+    CON_DBUS_VAL(false);
     res=kdesvndInterface.get_login(realm,username);
     if (!res.isValid()) {
         kWarning() << "Unexpected reply type";
@@ -401,6 +382,9 @@ bool KioListener::contextAddListItem(svn::DirEntries*entries, const svn_dirent_t
         return false;
     }
     if (par) {
+        if (par->checkKioCancel()) {
+            m_Canceld = true;
+        }
         par->listSendDirEntry(svn::DirEntry(path, dirent,lock));
         return true;
     }
@@ -413,6 +397,9 @@ bool KioListener::contextAddListItem(svn::DirEntries*entries, const svn_dirent_t
 void KioListener::contextProgress(long long int cur, long long int max)
 {
     if (par) {
+        if (par->checkKioCancel()) {
+            m_Canceld = true;
+        }
         par->contextProgress(cur,max);
     }
 }
