@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
+ *   Copyright (C) 2005-2009 by Rajko Albrecht                             *
  *   ral@alwins-world.de                                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -551,6 +551,7 @@ void Commitmsg_impl::hideButtons(bool how)
         m_UnmarkUnversioned->hide();
         m_DiffItem->hide();
         m_HideNewItems->hide();
+        m_SelectAllButton->hide();
     }
     else
     {
@@ -558,6 +559,7 @@ void Commitmsg_impl::hideButtons(bool how)
         m_UnmarkUnversioned->show();
         m_DiffItem->show();
         m_HideNewItems->show();
+        m_SelectAllButton->show();
     }
 }
 
@@ -572,6 +574,14 @@ void Commitmsg_impl::markUnversioned(bool mark)
     m_CurrentModel->markItems(mark,CommitActionEntry::ADD_COMMIT);
 }
 
+void Commitmsg_impl::slotSelectAll()
+{
+    if (!m_CurrentModel) {
+        return;
+    }
+    m_CurrentModel->markItems(true,CommitActionEntry::ALL);
+}
+
 void Commitmsg_impl::hideNewItems(bool how)
 {
     if (!m_CurrentModel) {
