@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
+ *   Copyright (C) 2005-2009 by Rajko Albrecht                             *
  *   ral@alwins-world.de                                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,19 +20,19 @@
 #include "ccontextlistener.h"
 #include "src/settings/kdesvnsettings.h"
 #include "src/ksvnwidgets/authdialogimpl.h"
-#include "src/ksvnwidgets/logmsg_impl.h"
+#include "src/ksvnwidgets/commitmsg_impl.h"
 #include "src/ksvnwidgets/ssltrustprompt_impl.h"
 #include "src/ksvnwidgets/pwstorage.h"
 
 #include <klocale.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kinputdialog.h>
-#include <kpassdlg.h>
+#include <kpassworddialog.h>
 #include <kdebug.h>
 #include <kfiledialog.h>
+#include <kmessagebox.h>
 
-#include <qmap.h>
-#include <qtextstream.h>
+#include <QTextStream>
 #include <qthread.h>
 
 class CContextListenerData
@@ -73,14 +73,14 @@ const QString CContextListener::action_strings[]={
     I18N_NOOP("Update"), //svn_wc_notify_update_update
     I18N_NOOP("Update complete"),
     I18N_NOOP("Update external module"),
-    QString::null, // status completed - will not send is just noisy
+    QString(), // status completed - will not send is just noisy
     I18N_NOOP("Status on external"), //svn_wc_notify_status_external
     I18N_NOOP("Commit Modified"),
     I18N_NOOP("Commit Added"),
     I18N_NOOP("Commit Deleted"),
     I18N_NOOP("Commit Replaced"),
-    QString::null, //tx delta -> making ticks instead
-    QString::null, //svn_wc_notify_blame_revision - using ticks
+    QString(), //tx delta -> making ticks instead
+    QString(), //svn_wc_notify_blame_revision - using ticks
     I18N_NOOP("Locking"),
     I18N_NOOP("Unlocked"),
     I18N_NOOP("Lock failed"),
@@ -88,13 +88,13 @@ const QString CContextListener::action_strings[]={
 };
 
 const QString CContextListener::notify_state_strings[]={
-    QString::null, // = 0
-    QString::null,
+    QString(), // = 0
+    QString(),
     I18N_NOOP("unchanged"),
     I18N_NOOP("item wasn't present"),
     I18N_NOOP("unversioned item obstructed work"),
     // I18N_NOOP("Pristine state was modified."), // should send a signal with path instead of message?
-    QString::null,
+    QString(),
     I18N_NOOP("Modified state had mods merged in."),
     I18N_NOOP("Modified state got conflicting mods.")
 };
@@ -102,20 +102,21 @@ const QString CContextListener::notify_state_strings[]={
 QString CContextListener::NotifyAction(svn_wc_notify_action_t action)
 {
     if (action>=smax_actionstring||action<0) {
-        return QString::null;
+        return QString();
     }
-    return action_strings[action].isEmpty()?QString::null:i18n(action_strings[action]);
+    return action_strings[action].isEmpty() ? QString(): /*i18n(*/action_strings[action]/*)*/;
 }
 
 QString CContextListener::NotifyState(svn_wc_notify_state_t state)
 {
-    if (state > svn_wc_notify_state_conflicted || state<0) return QString::null;
-    return notify_state_strings[state].isEmpty()?QString::null:i18n(notify_state_strings[state]);
+    if (state > svn_wc_notify_state_conflicted || state<0) return QString();
+    return notify_state_strings[state].isEmpty()?QString():/*i18n(*/notify_state_strings[state]/*)*/;
 }
 
 CContextListener::CContextListener(QObject *parent, const char *name)
- : QObject(parent, name), svn::ContextListener(),ref_count()
+ : QObject(parent), svn::ContextListener(),ref_count()
 {
+    setObjectName(name);
     m_Data = new CContextListenerData();
 }
 
@@ -133,8 +134,13 @@ bool CContextListener::contextGetCachedLogin (const QString & realm,QString & us
 
 bool CContextListener::contextGetSavedLogin (const QString & realm,QString & username,QString & password)
 {
+    if (!Kdesvnsettings::passwords_in_wallet()) {
+        return true;
+    }
+    emit waitShow(true);
     PwStorage::self()->getLogin(realm,username,password);
     PwStorage::self()->setCachedLogin(realm,username,password);
+    emit waitShow(false);
     /* the return value isn't interesting to us... */
     return true;
 }
@@ -183,11 +189,14 @@ void CContextListener::contextNotify (const char *path,
                     svn_wc_notify_state_t prop_state,
                     svn_revnum_t revision)
 {
+    Q_UNUSED(mime_type);
+    Q_UNUSED(prop_state);
+
     QString msg;
     QString aString = NotifyAction(action);
 
     if (!aString.isEmpty()) {
-        QTextStream ts(&msg,IO_WriteOnly);
+        QTextStream ts(&msg,QIODevice::WriteOnly);
         ts << NotifyAction(action) << " " << QString::FROMUTF8(path);
         if (revision>-1) {
             ts << " (Rev "<<revision<<")";
@@ -234,7 +243,7 @@ bool CContextListener::contextGetLogMessage (QString & msg,const svn::CommitItem
 {
     bool isOk = false;
     emit waitShow(true);
-    QString logMessage = Logmsg_impl::getLogmessage(items,&isOk,0,0,0);
+    QString logMessage = Commitmsg_impl::getLogmessage(items,&isOk,0,0,0);
     if (isOk) {
         msg = logMessage;
     }
@@ -267,11 +276,14 @@ svn::ContextListener::SslServerTrustAnswer CContextListener::contextSslServerTru
 
 bool CContextListener::contextSslClientCertPrompt (QString & certFile)
 {
-    kdDebug()<<"CContextListener::contextSslClientCertPrompt "
-        << certFile << endl;
+    kDebug(9510)<< certFile << endl;
     emit waitShow(true);
-    QString afile = KFileDialog::getOpenFileName(QString::null,
-        QString::null,
+//     QString afile = KFileDialog::getOpenFileName(QString(),
+//         QString(),
+//         0,
+//         i18n("Open a file with a #PKCS12 certificate"));
+    QString afile = KFileDialog::getOpenFileName(KUrl(),
+        QString(),
         0,
         i18n("Open a file with a #PKCS12 certificate"));
     emit waitShow(false);
@@ -293,11 +305,15 @@ bool CContextListener::contextSslClientCertPwPrompt (QString & password,
 {
     maysave = false;
     emit waitShow(true);
-    QCString npass;
+    QString npass;
     int keep = 1;
-    int res = KPasswordDialog::getPassword(npass,
-        i18n("Enter password for realm %1").arg(realm),
-        &keep);
+    KPasswordDialog dlg(0);
+    dlg.setPrompt(i18n("Enter password for realm %1",realm));
+    dlg.setWindowTitle(realm);
+    int res = dlg.exec();
+    if (res == QDialog::Accepted)
+        npass = dlg.password();
+
     emit waitShow(false);
     if (res!=KPasswordDialog::Accepted) {
         return false;
@@ -339,7 +355,7 @@ QStringList CContextListener::failure2Strings(apr_uint32_t acceptedFailures)
 
 QString CContextListener::translate(const QString&what)
 {
-    return i18n(what);
+    return i18n(what.toLocal8Bit());
 }
 
 /*!
@@ -350,4 +366,19 @@ void CContextListener::contextProgress(long long int current, long long int max)
     emit netProgress(current,max);
 }
 
+void CContextListener::maySavePlaintext(svn_boolean_t *may_save_plaintext, const QString&realmstring)
+{
+    emit waitShow(true);
+    if (may_save_plaintext) {
+        QString question = i18n("%1\nRealy store password as plain text?",realmstring);
+        QString head = i18n("Save password");
+        if (KMessageBox::questionYesNo(0,question,head)==KMessageBox::Yes) {
+            *may_save_plaintext = true;
+        } else {
+            *may_save_plaintext = false;
+        }
+    }
+    emit waitShow(false);
+}
+
 #include "ccontextlistener.moc"
