@@ -1,28 +1,32 @@
 /***************************************************************************
- *   Copyright (C) 2006-2007 by Rajko Albrecht                             *
+ *   Copyright (C) 2006-2009 by Rajko Albrecht                             *
  *   ral@alwins-world.de                                                   *
  *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ * This program is free software; you can redistribute it and/or           *
+ * modify it under the terms of the GNU Lesser General Public              *
+ * License as published by the Free Software Foundation; either            *
+ * version 2.1 of the License, or (at your option) any later version.      *
  *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
+ * This program is distributed in the hope that it will be useful,         *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
+ * Lesser General Public License for more details.                         *
  *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
+ * You should have received a copy of the GNU Lesser General Public        *
+ * License along with this program (in the file LGPL.txt); if not,         *
+ * write to the Free Software Foundation, Inc., 51 Franklin St,            *
+ * Fifth Floor, Boston, MA  02110-1301  USA                                *
+ *                                                                         *
+ * This software consists of voluntary contributions made by many          *
+ * individuals.  For exact contribution history, see the revision          *
+ * history and logs, available at http://kdesvn.alwins-world.de.           *
  ***************************************************************************/
-#include "svnqt/repositorydata.hpp"
-#include "svnqt/svnqt_defines.hpp"
-#include "svnqt/exception.hpp"
-#include "svnqt/repositorylistener.hpp"
-#include "svnqt/svnfilestream.hpp"
-#include "svnqt/repoparameter.hpp"
+#include "svnqt/repositorydata.h"
+#include "svnqt/svnqt_defines.h"
+#include "svnqt/exception.h"
+#include "svnqt/repositorylistener.h"
+#include "svnqt/svnfilestream.h"
+#include "svnqt/repoparameter.h"
 
 #include <svn_fs.h>
 #include <svn_path.h>
@@ -93,7 +97,7 @@ svn_error_t*RepositoryData::cancel_func(void*baton)
 {
     RepositoryListener*m_L = (RepositoryListener*)baton;
     if (m_L && m_L->isCanceld()) {
-        return svn_error_create (SVN_ERR_CANCELLED, 0, QString::FROMUTF8("Cancelled by user.").TOUTF8());
+        return svn_error_create (SVN_ERR_CANCELLED, 0, QObject::tr("Cancelled by user.").TOUTF8());
     }
     return SVN_NO_ERROR;
 }
@@ -177,7 +181,7 @@ svn_error_t * RepositoryData::CreateOpen(const CreateRepoParameter&params)
 
     if (svn_path_is_url(repository_path)) {
         return svn_error_createf(SVN_ERR_CL_ARG_PARSING_ERROR, NULL,
-            "'%s' is an URL when it should be a path",repository_path);
+            QObject::tr("'%s' is an URL when it should be a path").TOUTF8(),repository_path);
     }
     SVN_ERR(svn_repos_create(&m_Repository, repository_path,
             NULL, NULL,config, fs_config,m_Pool));
@@ -194,7 +198,7 @@ svn_error_t * RepositoryData::CreateOpen(const CreateRepoParameter&params)
 svn_error_t* RepositoryData::dump(const QString&output,const svn::Revision&start,const svn::Revision&end, bool incremental, bool use_deltas)
 {
     if (!m_Repository) {
-        return svn_error_create(SVN_ERR_CANCELLED,0,"No repository selected.");
+        return svn_error_create(SVN_ERR_CANCELLED,0,QObject::tr("No repository selected.").TOUTF8());
     }
     Pool pool;
     svn::stream::SvnFileOStream out(output);
@@ -211,7 +215,7 @@ svn_error_t* RepositoryData::dump(const QString&output,const svn::Revision&start
 svn_error_t* RepositoryData::loaddump(const QString&dump,svn_repos_load_uuid uuida, const QString&parentFolder, bool usePre, bool usePost)
 {
     if (!m_Repository) {
-        return svn_error_create(SVN_ERR_CANCELLED,0,"No repository selected.");
+        return svn_error_create(SVN_ERR_CANCELLED,0,QObject::tr("No repository selected.").TOUTF8());
     }
     svn::stream::SvnFileIStream infile(dump);
     RepoOutStream backstream(this);
